@@ -40,6 +40,7 @@ except:
 from lib.lib import banner_notification, list_presence_users
 from lib.server import Bonjour_server
 from lib.sms_listener import Sms_listener
+from lib.call_listener import Call_listener
 from lib.scheduler import Scheduler
 from lib.lib import logger
 from lib.friend import Friend
@@ -146,7 +147,8 @@ class Ui_MainWindow(QtCore.QObject):
         self.main_window.conf_dialog = Config_dialog(self.main_window)
         # Load saved config
         config.init_profile()
-        config.init_useusb()
+        if config.useusb == QtCore.Qt.Checked:
+            config.start_useusb()
 
         ### Menu
         self.menubar = MenuBar(self.main_window)
@@ -261,7 +263,7 @@ class Ui_MainWindow(QtCore.QObject):
         icon = QtGui.QIcon('/usr/share/icons/hicolor/48x48/hildon'
                            '/general_refresh.png')
         vars = {}
-        vars['version'] = "1.5.1"
+        vars['version'] = "1.6.0"
         message = QtCore.QString("""<center><h2>HeySms</h2></center>"""
                                  """<center>Version: %(version)s</center>"""
                                  """<br/>Visite web site: <a href="http://talk.maemo.org/showthread.php?t=84705">Here</a> """
@@ -289,7 +291,9 @@ def main():
             sleep(0.1)
         logger.debug("Restore profile")
         config.restore_profile()
-        config.restore_useusb()
+        if config.useusb == QtCore.Qt.Checked:
+            logger.debug("Restore USB")
+            config.restore_useusb()
 
     opt_parser = OptionParser()
     opt_parser.add_option("-d", "--debug", dest="debug_mode",
@@ -308,6 +312,9 @@ def main():
     ui.setupUi(main_window)
     config.parent = ui
 
+    ui.call_listener = Call_listener(ui)
+    ui.call_listener.start()
+    logger.debug("Call_listener started")
     ui.sms_listener = Sms_listener(ui)
     ui.sms_listener.start()
     logger.debug("Sms_listener started")
